@@ -731,6 +731,7 @@ int MIMEH_are_headers_RFC822( char *headers )
 	lc_headers = strdup(headers);
 	if (lc_headers == NULL) return 0;
 
+	//PLD_strlower((unsigned char *)lc_headers);
 	PLD_strlower(lc_headers);
 
 	DMIMEH LOGGER_log("%s:%d:MIMEH_are_headers_RFC822:DEBUG:----(lowercase)----\n%s\n----",FL,lc_headers);
@@ -1073,7 +1074,7 @@ Input:
 Output:
 Errors:
 ------------------------------------------------------------------------*/
-int MIMEH_read_headers( FFGET_FILE *f )
+int MIMEH_read_headers( struct MIMEH_header_info *hinfo, FFGET_FILE *f )
 {
 	char buffer[_MIMEH_STRLEN_MAX+1];
 	int totalsize=0;
@@ -1122,6 +1123,10 @@ int MIMEH_read_headers( FFGET_FILE *f )
 			linesize = strlen(linestart);
 			lineend = linestart +linesize;
 
+			if (strstr(linestart,"\r\n")) hinfo->crlf_count++;
+			else if (strstr(linestart,"\r\r")) hinfo->crcr_count++;
+			else if (strchr(linestart,'\n')) hinfo->lf_count++;
+
 			if (MIMEH_DNORMAL)LOGGER_log("%s:%d:MIMEH_read_headers: Data In=[sz=%d:tb=%d:mem=%p]'%s'",FL, linesize, f->trueblank, glb.headerline, buffer);
 
 			// If we are being told to copy the input data to an output file
@@ -1579,6 +1584,7 @@ int MIMEH_parse_header_parameter( struct MIMEH_header_info *hinfo,  char *data,
 	// Duplicate and convert to lowercase the header data
 	//		that we have been provided with.
 	hl = strdup(data);
+	//PLD_strlower((unsigned char *)hl);
 	PLD_strlower(hl);
 
 	if (MIMEH_DNORMAL) LOGGER_log("%s:%d:MIMEH_parse_header_parameter:DEBUG: Seeking '%s' in '%s'", FL, searchstr, hl);
@@ -1745,6 +1751,8 @@ int MIMEH_parse_header_parameter( struct MIMEH_header_info *hinfo,  char *data,
 						string++;
 						while ((*string != '\0')&&(*string == '\"')){ string++; MIMEH_set_defect(hinfo,MIMEH_DEFECT_MULTIPLE_QUOTES); }
 
+						if (*string == '\0') break; // 20071030-0958: Added by Claudio Jeker - prevents overflow.
+
 						// Find the next quote which isn't sequential to the above
 						//		quotes that we just skipped over
 						string_end = strchr(string+1, '\"');
@@ -1974,7 +1982,8 @@ int MIMEH_parse_contenttype( char *header_name, char *header_value, struct MIMEH
 
 /** 20041216-1106:PLD: Increase our sanity **/
 		hinfo->sanity++;
-		PLD_strlower( header_value );
+		PLD_strlower(  header_value );
+		PLD_strlower(  header_value );
 		q = header_value;
 
 		if (strstr(q,"multipart/appledouble")) hinfo->content_type = _CTYPE_MULTIPART_APPLEDOUBLE;
@@ -2929,6 +2938,11 @@ int MIMEH_headers_get( struct MIMEH_header_info *hinfo, FFGET_FILE *f )
 	hinfo->content_transfer_encoding = 0;
 	hinfo->boundary_located = 0;
 
+	hinfo->crlf_count=0;
+	hinfo->crcr_count=0;
+	hinfo->lf_count=0;
+	snprintf(hinfo->delimeter,sizeof(hinfo->delimeter),"\r\n");
+
 	// Initialise header defects array.
 	hinfo->header_defect_count = 0;
 	memset(hinfo->defects, 0, _MIMEH_DEFECT_ARRAY_SIZE);
@@ -2938,9 +2952,12 @@ int MIMEH_headers_get( struct MIMEH_header_info *hinfo, FFGET_FILE *f )
 
 	// Read from the file, the headers we need
 	FFGET_set_watch_SDL(1);
-	result = MIMEH_read_headers(f);
+	result = MIMEH_read_headers(hinfo, f);
 	FFGET_set_watch_SDL(0);
 
+	if (hinfo->lf_count > hinfo->crlf_count) { 
+		snprintf(hinfo->delimeter,sizeof(hinfo->delimeter),"\n");
+	}
 
 	// If we ran out of input whilst looking at headers, then, we basically
 	// flag this, free up the headers, and return.
