@@ -1,7 +1,7 @@
 #ifndef MIMEHEADERS
 #define MIMEHEADERS
 
-#define MIMEH_VERSION "200603032208"
+#define MIMEH_VERSION "200811151148"
 
 #define _CTYPE_RANGE 99
 
@@ -139,6 +139,11 @@ struct MIMEH_header_info
 /** 20051117-0932:PLD: Will be non-zero if email is MIME **/
 	int is_mime;
 
+	char delimeter[3];
+	int crlf_count; // 200811151149:PLD: Tally's the number of CRLF lines
+	int crcr_count; // 200811151149:PLD: Tally's the number of CRLF lines
+	int lf_count; // 200811151149:PLD: Tally's the number of  LF only lines
+
 };
 
 
@@ -190,7 +195,7 @@ char *MIMEH_get_doubleCR_name( void );
 
 int MIMEH_set_header_longsearch( int level );
 
-int MIMEH_read_headers( FFGET_FILE *f );
+int MIMEH_read_headers( struct MIMEH_header_info *hinfo, FFGET_FILE *f );
 
 int MIMEH_headers_get( struct MIMEH_header_info *hinfo, FFGET_FILE *f );
 int MIMEH_headers_process( struct MIMEH_header_info *hinfo, char *headers );
