@@ -23,15 +23,6 @@ contributed by Don Lafontaine <lafont02@cn.ca>
 #include "logger.h"
 #include "ffget.h"
 
-#ifndef FL
-#define FL __FILE__,__LINE__
-#endif
-
-#define FFGET_VERSION	"1.0.0.7"
-#define FFGET_LASTUPDATED "200707091500"
-
-#define FFGET_DNORMAL   ((FFGET_debug >= FFGET_DEBUG_NORMAL  ))
-#define FFGET_DPEDANTIC ((FFGET_debug >= FFGET_DEBUG_PEDANTIC))
 
 /* GLOBALS */
 int ffget_linesize=0;
@@ -225,7 +216,7 @@ Errors:
 int FFGET_setstream( FFGET_FILE *f, FILE *fi )
 {
 
-	memset(f,0,sizeof(FFGET_FILE)); // be pedantic - clear the struct
+//	memset(f,0,sizeof(FFGET_FILE)); // be pedantic - clear the struct
 
 	f->f = fi;
 	f->bytes = 0;
@@ -241,6 +232,8 @@ int FFGET_setstream( FFGET_FILE *f, FILE *fi )
 	f->FFEOF = 0;
 	f->FILEEND = 0;
 	f->last_block_read_from = -1;
+	f->linebreak = FFGET_LINEBREAK_NONE;
+	f->lastbreak[0] = '\0';
 	return 0;
 }
 
@@ -255,6 +248,7 @@ Errors:
 int FFGET_closestream( FFGET_FILE *f )
 {
 	f->startpoint = f->endpoint = NULL;
+	f->f = NULL;
 	return 0;
 }
 
@@ -428,6 +422,8 @@ char *FFGET_fgets( char *linein, int maxsize, FFGET_FILE *f )
 	int c, nextchar;
 
 	f->trueblank = 0;
+	f->linebreak = FFGET_LINEBREAK_NONE;
+	f->lastbreak[0] = '\0';
 
 	if (f->FFEOF != 0)
 	{
@@ -537,8 +533,13 @@ char *FFGET_fgets( char *linein, int maxsize, FFGET_FILE *f )
 
 				if ( *crlfpos == '\n' )
 				{
+					f->linebreak = FFGET_LINEBREAK_LF;
+					snprintf(f->lastbreak,sizeof(f->lastbreak),"\n");
+
 					if ( *(crlfpos +1) == '\r' )
 					{
+						f->linebreak |= FFGET_LINEBREAK_CR;
+						snprintf(f->lastbreak,sizeof(f->lastbreak),"\n\r");
 						crlfpos++;
 						extra_char_kept = 1;
 					}
@@ -551,6 +552,9 @@ char *FFGET_fgets( char *linein, int maxsize, FFGET_FILE *f )
 
 				if ( (*crlfpos == '\r') )
 				{
+					f->linebreak = FFGET_LINEBREAK_CR;
+					snprintf(f->lastbreak,sizeof(f->lastbreak),"\r");
+
 					if ( *(crlfpos +1) == '\r' )
 					{
 						// A \r\r sequence has just been detected, set our doubleCR flag
@@ -558,6 +562,7 @@ char *FFGET_fgets( char *linein, int maxsize, FFGET_FILE *f )
 						// Look out for single \r's from here on, as they are now seen as
 						// 	EOL markers in Outlook.
 
+						f->linebreak = FFGET_LINEBREAK_CR;
 						FFGET_doubleCR=1;
 						FFGET_SDL_MODE=1;
 						crlfpos++;
@@ -566,7 +571,10 @@ char *FFGET_fgets( char *linein, int maxsize, FFGET_FILE *f )
 					} else if ( *(crlfpos +1) == '\n' ) {
 						// If we see a \n after our \r, then treat this as a single
 						// 	line delimeter if we are NOT in Single Delimeter mode
+						//
 
+						snprintf(f->lastbreak,sizeof(f->lastbreak),"\r\n");
+						f->linebreak |= FFGET_LINEBREAK_LF;
 						if (!FFGET_SDL_MODE) {
 						  	crlfpos++;
 							extra_char_kept = 1;
