@@ -53,11 +53,15 @@ char *PLD_strstr(char *haystack, char *needle, int insensitive)
 	if ((result != NULL)&&(insensitive > 0))
 	{
 		result = result -hs +haystack;
-		free(hs);
-		free(ne);
+//		free(hs);
+//		free(ne);
 
 //		LOGGER_log("%s:%d:HIT - %s",FL, result );
 	}
+	if (insensitive) {
+		free(hs);
+		free(ne);
+	}
 
 	return result;
 }
@@ -356,17 +360,18 @@ Purpose:       Converts a string to lowercase
 Input:         char *convertme : string to convert
 Output:
 Errors:
+Comments:		Really need to validate against high-ASCII chars.
+					Tested against strings like;
+						Logo de la République française
+						Македонски
+
 ------------------------------------------------------------------------*/
 int PLD_strlower( char *convertme )
 {
 
-	// Updates:
-	//	09-11-2002 - changed from 'char *' to 'unsigned char *' to deal with
-	//		non-ASCII characters ( ie, french ).  Pointed out by Emmanuel Collignon
-
 	char *c = convertme;
 
-	while ( *c != '\0') {*c = tolower((int)*c); c++;}
+	while ( *c != '\0') {*c = (unsigned char)tolower((int)*c); c++;}
 
 	return 0;
 }
@@ -653,8 +658,8 @@ char *PLD_strreplace_general( struct PLD_strreplace *replace_details )
 
 	*new_p = '\0';
 
-	if (replace_details->source != NULL) free (replace_details->source);
-	replace_details->source = new_buffer;
+//	if (replace_details->source != NULL) free (replace_details->source);
+//	replace_details->source = new_buffer;
 	return new_buffer;
 }
 
