@@ -7,6 +7,7 @@
 #include <unistd.h>
 #include <errno.h>
 
+#include "logger.h"
 #include "qpe.h"
 
 #define CRLF "\r\n"
@@ -90,11 +91,11 @@ int qp_encode( char *out, size_t out_size, char *in, size_t in_size )
 				charout_size = 1;
 			}
 
-			if (current_line_length +charout_size >= 76) {
+			if (current_line_length +charout_size >= 79) { // Was 76, updated to fix Outlook problems
 				//snprintf(op, out_remaining, "%s=\r\n", paragraph);
 				snprintf(op, out_remaining, "%s=\r\n", paragraph);
-				op+= strlen(paragraph) +3; /** jump the output + =\r\n **/
-				out_remaining-= (strlen(paragraph) +3);
+				op+= strlen(paragraph);// +3; /** jump the output + =\r\n **/
+				out_remaining-= (strlen(paragraph)); // Was +3, updated to fix Outlook problems
 
 				QPD fprintf(stdout, "Soft break (%d + %d > 76 char) for '%s'\n", current_line_length, charout_size, paragraph);
 				
@@ -129,6 +130,7 @@ int qp_encode( char *out, size_t out_size, char *in, size_t in_size )
 
 int qp_encode_from_file( char *fname )
 {
+	size_t bc;
 	struct stat st;
 	int stat_result;
 	char *in_buffer;
@@ -159,7 +161,8 @@ int qp_encode_from_file( char *fname )
 
 
 	f = fopen( fname, "r" );
-	fread( in_buffer, 1, in_size, f );
+	bc = fread( in_buffer, 1, in_size, f );
+	if (bc != in_size) LOGGER_log("%s:%d:qp_encode_from_file:ERROR: Read %d bytes but requested %d", FL, bc, in_size);
 	fclose(f);
 
 	/** zero terminate the buffer -- uhuh, if you forget that you'll wonder why
